@@ -28,8 +28,8 @@
 // KDE Includes
 
 #include <kdebug.h>
-#include <klocale.h>
-#include <klistview.h>
+#include <tdelocale.h>
+#include <tdelistview.h>
 #include <kpushbutton.h>
 
 // ----------------------------------------------------------------------------
@@ -52,7 +52,7 @@ KForecastView::KForecastView(TQWidget *parent, const char *name) :
   for(int i=0; i < MaxViewTabs; ++i)
     m_needReload[i] = false;
 
-  KConfig *config = KGlobal::config();
+  TDEConfig *config = TDEGlobal::config();
   config->setGroup("Last Use Settings");
   m_tab->setCurrentPage(config->readNumEntry("KForecastView_LastType", 0));
 
@@ -83,7 +83,7 @@ void KForecastView::slotTabChanged(TQWidget* _tab)
   ForecastViewTab tab = static_cast<ForecastViewTab>(m_tab->indexOf(_tab));
 
   // remember this setting for startup
-  KConfig *config = KGlobal::config();
+  TDEConfig *config = TDEGlobal::config();
   config->setGroup("Last Use Settings");
   config->writeEntry("KForecastView_LastType", tab);
 
@@ -447,7 +447,7 @@ void KForecastView::loadAdvancedView(void)
       advancedItem->setText(it_c, amount, amountMM.isNegative());
       it_c++;
 
-      TQString dateString = KGlobal::locale()->formatDate(minDate, true);
+      TQString dateString = TDEGlobal::locale()->formatDate(minDate, true);
       advancedItem->setText(it_c, dateString, amountMM.isNegative());
       it_c++;
     }
@@ -464,7 +464,7 @@ void KForecastView::loadAdvancedView(void)
       advancedItem->setText(it_c, amount, amountMM.isNegative());
       it_c++;
 
-      TQString dateString = KGlobal::locale()->formatDate(maxDate, true);
+      TQString dateString = TDEGlobal::locale()->formatDate(maxDate, true);
       advancedItem->setText(it_c, dateString, amountMM.isNegative());
       it_c++;
     }
