@@ -66,11 +66,11 @@ instead of the value that is stored locally.
 class KDCHART_EXPORT KDChartPropertySet :public TQObject
 {
     Q_OBJECT
-    TQ_OBJECT
-    Q_ENUMS( SpecialDataPropertyID )
+    
+    TQ_ENUMS( SpecialDataPropertyID )
 
     // Required by TQSA
-    Q_ENUMS( PenStyle )
+    TQ_ENUMS( PenStyle )
 
     friend class KDChartParams;
 
